@@ -6,7 +6,7 @@ del get_versions
 
 from aeppl.logprob import logprob  # isort: split
 
-from aeppl.joint_logprob import joint_logprob
+from aeppl.joint_logprob import factorized_joint_logprob, joint_logprob
 from aeppl.printing import latex_pprint, pprint
 
 # isort: off
