@@ -155,7 +155,8 @@ def mixture_replace(fgraph, node):
 
 
 @_logprob.register(MixtureRV)
-def logprob_MixtureRV(op, value, *inputs, name=None, **kwargs):
+def logprob_MixtureRV(op, values, *inputs, name=None, **kwargs):
+    (value,) = values
     inputs = op.get_non_shared_inputs(inputs)
 
     subtensor_node = op.outputs[0].owner
